Notificacion class

Clase utilizado para las notificaciones del proyecto

  • key Clave que identifica de forma unica a la notificacion para eliminarlo
  • titulo La cabecera de la notificacion
  • descripcion Informacion adicional sobre la notificacion
  • icono Icono a utilizar para la notificacion
  • tipoNotificacion Existen 3 tipos de notificacion " error,notificaicon,navegacion"
  • onTap Si se trata del tipo de notificacion TipoNotificacion.navegacion se utiliza el onTap

Constructors

Notificacion({int indice = 0, String titulo = '', String descripcion = '', IconData? icono, TipoNotificacion? tipoNotificacion, String url = '', VoidCallback? onTap})
const

Properties

descripcion String
final
hashCode int
The hash code for this object.
no setterinherited
icono IconData?
final
indice int
final
onTap VoidCallback?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
tipoNotificacion TipoNotificacion
final
titulo String
final
url String
final

Methods

copyWith({String? titulo, int? indice, String? descripcion, IconData? icono, TipoNotificacion? tipoNotificacion, String? url, VoidCallback? onTap}) Notificacion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited