ButtonWidget class

Inheritance

Constructors

ButtonWidget({Key? key, required Widget child})
const
ButtonWidget.filled({required String titulo, required dynamic onChanged(), double? maxWidth, TipoBoton? tipoBoton})
Por default este boton ocupa el menor ancho posible acomodando su contenido, al pasarle un maxWidth será para hacerlo más ancho botones
factory
ButtonWidget.fromValue({required String titulo, required ButomType tipo, required dynamic onChanged(), double? maxWidth, Color? colorTexto, Color? borderColor})
factory
ButtonWidget.iconFilled({required String titulo, required IconData icono, required dynamic onChanged(), double? maxWidth, Color? colorTexto, Color? colorIcono})
Por default este boton ocupa el menor ancho posible acomodando su contenido, al pasarle un maxWidth será para hacerlo más ancho botones
factory
ButtonWidget.iconOutlined({required String titulo, required IconData icono, required dynamic onChanged(), double? maxWidth, Color? borderColor})
Por default este boton ocupa el menor ancho posible acomodando su contenido, al pasarle un maxWidth será para hacerlo más ancho botones
factory
ButtonWidget.iconText({required String titulo, required IconData icono, required dynamic onChanged(), double? maxWidth, Color? colorTexto, Color? colorIcono})
Por default este boton ocupa todo el ancho, al pasarle un maxWidth será para hacerlo más angosto botones
factory
ButtonWidget.outlined({required String titulo, required dynamic onChanged(), double? maxWidth, Color? borderColor})
Por default este boton ocupa el menor ancho posible acomodando su contenido, al pasarle un maxWidth será para hacerlo más ancho botones
factory
ButtonWidget.text({required String titulo, required dynamic onChanged(), double? maxWidth, Color? colorTexto})
Por default este boton ocupa el menor ancho posible acomodando su contenido, al pasarle un maxWidth será para hacerlo más ancho botones
factory
ButtonWidget.widgetOutlined({required String titulo, required Widget widget, required dynamic onChanged(), Color? colorTexto, double? maxWidth, double? maxheight, Color? borderColor})
Por default este botonpuede usarse para poner una imagen widget alado del texto, al pasarle un maxWidth será para hacerlo más ancho botones
factory

Properties

child → Widget
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited