ColumnTabla class
- Inheritance
-
- Object
- ChangeNotifier
- ColumnTabla
Constructors
- ColumnTabla({required String clave, required String titulo, bool agregaPrefijoData = true, double ancho = 0, bool ocultar = false, TipoDato tipoDato = TipoDato.string, int ordenTabla = 0, Alignment? alineacion, OrientacionBusqueda orientacion = OrientacionBusqueda.derecha, ColumnAnchoMode? anchoMode = ColumnAnchoMode.ajustatTitulo, bool isFiltrar = true})
Properties
- agregaPrefijoData → bool
-
Esto es utilizado para las consultas.
Si es true se agrega el prefijo data. a la clave
que es lo que se pide para las consultas de getKey para campos
que se encuentren dentro de data
final
- alignment → Alignment
-
final
- ancho ↔ double
-
getter/setter pair
- anchoMode → ColumnAnchoMode?
-
final
- clave → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isFiltrar → bool
-
final
-
key
→ GlobalKey<
State< StatefulWidget> > -
final
- ocultar ↔ bool
-
getter/setter pair
- ordenTabla → int
-
final
- orientacion → OrientacionBusqueda
-
Orientacion del overlay
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tipoDato → TipoDato
-
final
- titulo → String
-
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
changeAncho(
double ancho) → void -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited